/******************************************************************************
CLASSE DIALANOTACOES
CRIADO: 31-10-2008
ALTERADO: 15-01-2009
AUTOR: LUIS VASQUEZ - luis@comunidadeabiblia.net
WEB: www.comunidadeabiblia.net
--------------------------------aBblia Software-------------------------------
******************************************************************************/

#include "dialanotacoes.h"

#include "readbiblia.h"
#include "bancouser.h"
#include "exportar.h"


DialAnotacoes::DialAnotacoes():DialBase(){
	setWindowTitle("Listar Anotaes - " + (const QString&)NOME);
	setMinimumSize( QSize( 380, 435 ) );
	setMaximumSize( QSize( 380, 435 ) );

	QFont fonte = QFont("Bitstream", FONTE_MEDIA);
	box = new QGroupBox( this );
	box->setTitle("Captulos que possuem anotaes salvas");
	box->setFont(fonte);

	fonte = QFont("Bitstream", FONTE_PEQUENA);
	lblLivro = new QLabel( "Livro", box );
	lblLivro->setFont(fonte);
	
	lblCapitulo = new QLabel( "Captulo", box );
	lblCapitulo->setFont(fonte);
	
	lblAnotacao = new QLabel( "Anotao", box );
	lblAnotacao->setFont(fonte);

	fonte = QFont("Bitstream", FONTE_MEDIA);
	cmbLivro = new QComboBox( box );
	cmbLivro->setFont(fonte);
	cmbLivro->setToolTip("Livros que possuem\nanotaes salvas");

	cmbCapitulo = new QComboBox( box );
	cmbCapitulo->setFont(fonte);
	cmbCapitulo->setToolTip("Captulos do livro selecionado\nque possuem anotaes salvas");
	
	btnLer = new QPushButton("Ler", box);
	btnLer->setFont(fonte);
	btnLer->setDefault(TRUE);
	btnLer->setToolTip("Ler captulo selecionado");
	
	caixaTextoRodape = new QTextEdit(box);
	caixaTextoRodape->setFont(fonte);
	caixaTextoRodape->setReadOnly(TRUE);
	caixaTextoRodape->setToolTip("Prvia da anotao selecionada");
	
	btnExcluir = new QPushButton("Excluir", box);
	btnExcluir->setFont(fonte);
	btnExcluir->setToolTip("Excluir anotao selecionada");
	
	btnExportar = new QPushButton("Exportar", box);
	btnExportar->setFont(fonte);
	btnExportar->setToolTip("Exportar todas anotaes");
	
	btnImportar = new QPushButton("Importar", box);
	btnImportar->setFont(fonte);
	btnImportar->setToolTip("Importar anotaes");
	
	carregarCombosAnotacoes();
	
	fonte = QFont("Bitstream", FONTE_PEQUENA);
	chkFecharAlto = new QCheckBox("Fechar tela automaticamente", this);
	chkFecharAlto->setFont(fonte);
	chkFecharAlto->setChecked(true);
	
	redefinirObjetosCancelar();
	
	QObject::connect( btnLer, SIGNAL(clicked() ), this, SLOT(exibirAnot() ) );
	QObject::connect( btnExcluir, SIGNAL(clicked() ), this, SLOT(slotExcluirAnot() ) );
	QObject::connect( btnExportar, SIGNAL(clicked() ), this, SLOT(slotExportarAnot() ) );
	QObject::connect( btnImportar, SIGNAL(clicked() ), this, SLOT(slotImportarAnot() ) );
	QObject::connect( cmbLivro, SIGNAL( activated (const QString&) ), this, SLOT(carregarCmbCapitulo() ) );
	QObject::connect( cmbCapitulo, SIGNAL( activated (const QString&) ), this, SLOT(carregarCaixaTextoRodape() ) );

	box->setGeometry( QRect( 10, 10, 360, 375 ) );
	lblLivro->setGeometry( QRect( 10, 25, 100, 25 ) );
	lblCapitulo->setGeometry( QRect( 220, 25, 100, 25 ) );
	cmbLivro->setGeometry( QRect( 10, 45, 200, 25 ) );
	cmbCapitulo->setGeometry( QRect( 220, 45, 50, 25 ) );
	btnLer->setGeometry( QRect( 280, 45, 70, 25) );
	lblAnotacao->setGeometry( QRect( 10, 70, 100, 25 ) );
	caixaTextoRodape->setGeometry( QRect( 10, 90, 340, 240) );
	btnExcluir->setGeometry( QRect( 10, 340, 70, 25) );
	btnExportar->setGeometry( QRect( 200, 340, 70, 25) );
	btnImportar->setGeometry( QRect( 280, 340, 70, 25) );
	
	btnCancelar->setGeometry( QRect( width() - 80, height() - 35, 70, 25 ) );
	chkFecharAlto->setGeometry( QRect( 10, height() - 30, 200, 25) );
}

void DialAnotacoes::carregarCombosAnotacoes(){
	cmbLivro->clear();
	cmbCapitulo->clear();
	caixaTextoRodape->clear();
	if (!bancoUser.getListLivroAnotacao().isEmpty()){
		cmbLivro->addItems(bancoUser.getListLivroAnotacao());
		carregarCmbCapitulo();
		
		cmbLivro->setEnabled(true);
		cmbCapitulo->setEnabled(true);
		btnLer->setEnabled(true);
		btnExcluir->setEnabled(true);
		btnExportar->setEnabled(true);
		caixaTextoRodape->setEnabled(true);
	}
	else{
		cmbLivro->setEnabled(false);
		cmbCapitulo->setEnabled(false);
		btnLer->setEnabled(false);
		btnExcluir->setEnabled(false);
		btnExportar->setEnabled(false);
		caixaTextoRodape->setEnabled(false);
	}
}
void DialAnotacoes::carregarCaixaTextoRodape(){
	BancoUser bancoUser;
	caixaTextoRodape->setText( bancoUser.getAnotacao(cmbLivro->currentText(), cmbCapitulo->currentText()) );
}
void DialAnotacoes::carregarCmbCapitulo(){
	BancoUser bancoUser;
	cmbCapitulo->clear();
	cmbCapitulo->addItems(bancoUser.getListCapituloAnotacao(cmbLivro->currentText()));
	caixaTextoRodape->setText( bancoUser.getAnotacao(cmbLivro->currentText(), cmbCapitulo->currentText()) );
}
void DialAnotacoes::exibirAnot(){
	qApp->setOverrideCursor( Qt::WaitCursor );
	ReadBiblia *mywidget = new ReadBiblia(cmbLivro->currentText() + " " +
				cmbCapitulo->currentText(), ferramentas.descobreTestamento(cmbLivro->currentText()));
	qApp->restoreOverrideCursor();
	mywidget->setParent(this->parentWidget(), Qt::Window);
	emit novaJanela(mywidget);
	if (chkFecharAlto->isChecked())
		close();
}
void DialAnotacoes::slotExportarAnot(){
	QString file = QFileDialog::getSaveFileName(this, tr("Salvar arquivo"), config.getDirHome(), tr("*.aba"));
	if (!file.isEmpty()){
		QFileInfo fi(file);
		config.setDirHome(fi.absoluteDir().path());
		
		if (!file.contains(".aba"))
			file += ".aba";
		QFile f(file);
		if (f.exists())
			f.remove();
		Exportar exp(file);
		qApp->setOverrideCursor( Qt::WaitCursor );
		exp.exportarAnotacoes();
		qApp->restoreOverrideCursor();
	}
}
void DialAnotacoes::slotImportarAnot(){
	QString file = QFileDialog::getOpenFileName(this, tr("Abrir arquivo"), config.getDirHome(), tr("*.aba"));
	if (!file.isEmpty()){
		QFileInfo fi(file);
		config.setDirHome(fi.absoluteDir().path());
		
		Exportar imp(file);
		qApp->setOverrideCursor( Qt::WaitCursor );
		if (imp.importarAnotacoes()){
			carregarCombosAnotacoes();
		}
		qApp->restoreOverrideCursor();
	}
}
void DialAnotacoes::slotExcluirAnot(){
	BancoUser bancoUser;
	AMessageBox aMsgBox;
	if (aMsgBox.yesNo("Tem certeza que deseja excluir esta anotao?","Excluir anotao")){
		qApp->setOverrideCursor( Qt::WaitCursor );
		bancoUser.delAnotacao(cmbLivro->currentText(),cmbCapitulo->currentText());
		carregarCombosAnotacoes();
		qApp->restoreOverrideCursor();
	}
}

